Package: vetiver
Title: Version, Share, Deploy, and Monitor Models
Version: 0.2.7
Authors@R: c(
    person("Julia", "Silge", , "julia.silge@posit.co", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0002-3671-836X")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: The goal of 'vetiver' is to provide fluent tooling to
    version, share, deploy, and monitor a trained model. Functions handle
    both recording and checking the model's input data prototype, and
    predicting from a remote API endpoint. The 'vetiver' package is
    extensible, with generics that can support many kinds of models.
License: MIT + file LICENSE
URL: https://vetiver.posit.co, https://rstudio.github.io/vetiver-r/,
        https://github.com/rstudio/vetiver-r/
BugReports: https://github.com/rstudio/vetiver-r/issues
Depends: R (>= 4.1)
Imports: bundle (>= 0.1.3), butcher (>= 0.4.0), cereal, cli, fs,
        generics, glue, hardhat, lifecycle, pins (>= 1.3.0), purrr,
        rapidoc, readr (>= 1.4.0), rlang (>= 1.1.0), tibble, vctrs,
        withr
Suggests: arrow, callr, caret, clustMixType, covr, curl, dplyr,
        flexdashboard, ggplot2, httpuv, httr, jsonlite, keras, knitr,
        LiblineaR, luz, mgcv, mlr3 (>= 0.17.0), mlr3data, mlr3learners,
        mockery, modeldata, parsnip, paws.machine.learning (>= 0.2.0),
        pingr, plotly, plumber (>= 1.0.0), probably (>= 1.2.0),
        quantregForest, ranger, recipes (>= 1.1.0), reticulate,
        rmarkdown, rpart, rsample, rsconnect, slider (>= 0.2.2),
        smdocker (>= 0.1.2), stacks, tensorflow, testthat (>= 3.1.8),
        tidyselect, torch, tune, vdiffr, workflows, xgboost, yardstick
VignetteBuilder: knitr
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Config/usethis/last-upkeep: 2025-12-11
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2025-12-12 20:39:29 UTC; juliasilge
Author: Julia Silge [cre, aut] (ORCID: <https://orcid.org/0000-0002-3671-836X>),
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Julia Silge <julia.silge@posit.co>
Repository: CRAN
Date/Publication: 2025-12-13 06:10:02 UTC
Built: R 4.6.0; ; 2026-04-29 09:40:20 UTC; unix
