# Generated by roxygen2: do not edit by hand

S3method(augment,vetiver_endpoint)
S3method(augment,vetiver_endpoint_sagemaker)
S3method(augment,vetiver_model)
S3method(format,vetiver_endpoint)
S3method(format,vetiver_endpoint_sagemaker)
S3method(format,vetiver_model)
S3method(glue_spec_summary,array)
S3method(glue_spec_summary,data.frame)
S3method(glue_spec_summary,default)
S3method(handler_predict,Learner)
S3method(handler_predict,default)
S3method(handler_predict,gam)
S3method(handler_predict,glm)
S3method(handler_predict,int_conformal_cv)
S3method(handler_predict,int_conformal_full)
S3method(handler_predict,int_conformal_quantile)
S3method(handler_predict,int_conformal_split)
S3method(handler_predict,keras.engine.training.Model)
S3method(handler_predict,kproto)
S3method(handler_predict,lm)
S3method(handler_predict,luz_module_fitted)
S3method(handler_predict,model_stack)
S3method(handler_predict,ranger)
S3method(handler_predict,recipe)
S3method(handler_predict,train)
S3method(handler_predict,workflow)
S3method(handler_predict,xgb.Booster)
S3method(handler_startup,Learner)
S3method(handler_startup,default)
S3method(handler_startup,gam)
S3method(handler_startup,int_conformal_cv)
S3method(handler_startup,int_conformal_full)
S3method(handler_startup,int_conformal_quantile)
S3method(handler_startup,int_conformal_split)
S3method(handler_startup,keras.engine.training.Model)
S3method(handler_startup,luz_module_fitted)
S3method(handler_startup,model_stack)
S3method(handler_startup,ranger)
S3method(handler_startup,recipe)
S3method(handler_startup,train)
S3method(handler_startup,workflow)
S3method(handler_startup,xgb.Booster)
S3method(map_request_body,array)
S3method(map_request_body,data.frame)
S3method(map_request_body,default)
S3method(predict,vetiver_endpoint)
S3method(predict,vetiver_endpoint_sagemaker)
S3method(predict,vetiver_model)
S3method(print,vetiver_endpoint)
S3method(print,vetiver_endpoint_sagemaker)
S3method(print,vetiver_model)
S3method(vetiver_create_description,Learner)
S3method(vetiver_create_description,default)
S3method(vetiver_create_description,gam)
S3method(vetiver_create_description,glm)
S3method(vetiver_create_description,int_conformal_cv)
S3method(vetiver_create_description,int_conformal_full)
S3method(vetiver_create_description,int_conformal_quantile)
S3method(vetiver_create_description,int_conformal_split)
S3method(vetiver_create_description,keras.engine.training.Model)
S3method(vetiver_create_description,kproto)
S3method(vetiver_create_description,lm)
S3method(vetiver_create_description,luz_module_fitted)
S3method(vetiver_create_description,model_stack)
S3method(vetiver_create_description,ranger)
S3method(vetiver_create_description,recipe)
S3method(vetiver_create_description,train)
S3method(vetiver_create_description,workflow)
S3method(vetiver_create_description,xgb.Booster)
S3method(vetiver_create_meta,Learner)
S3method(vetiver_create_meta,default)
S3method(vetiver_create_meta,gam)
S3method(vetiver_create_meta,int_conformal_cv)
S3method(vetiver_create_meta,int_conformal_full)
S3method(vetiver_create_meta,int_conformal_quantile)
S3method(vetiver_create_meta,int_conformal_split)
S3method(vetiver_create_meta,keras.engine.training.Model)
S3method(vetiver_create_meta,kproto)
S3method(vetiver_create_meta,luz_module_fitted)
S3method(vetiver_create_meta,model_stack)
S3method(vetiver_create_meta,ranger)
S3method(vetiver_create_meta,recipe)
S3method(vetiver_create_meta,train)
S3method(vetiver_create_meta,workflow)
S3method(vetiver_create_meta,xgb.Booster)
S3method(vetiver_prepare_model,Learner)
S3method(vetiver_prepare_model,default)
S3method(vetiver_prepare_model,gam)
S3method(vetiver_prepare_model,glm)
S3method(vetiver_prepare_model,int_conformal_cv)
S3method(vetiver_prepare_model,int_conformal_full)
S3method(vetiver_prepare_model,int_conformal_quantile)
S3method(vetiver_prepare_model,int_conformal_split)
S3method(vetiver_prepare_model,keras.engine.training.Model)
S3method(vetiver_prepare_model,kproto)
S3method(vetiver_prepare_model,lm)
S3method(vetiver_prepare_model,luz_module_fitted)
S3method(vetiver_prepare_model,model_stack)
S3method(vetiver_prepare_model,ranger)
S3method(vetiver_prepare_model,recipe)
S3method(vetiver_prepare_model,train)
S3method(vetiver_prepare_model,workflow)
S3method(vetiver_prepare_model,xgb.Booster)
S3method(vetiver_ptype,Learner)
S3method(vetiver_ptype,default)
S3method(vetiver_ptype,gam)
S3method(vetiver_ptype,glm)
S3method(vetiver_ptype,int_conformal_cv)
S3method(vetiver_ptype,int_conformal_full)
S3method(vetiver_ptype,int_conformal_quantile)
S3method(vetiver_ptype,int_conformal_split)
S3method(vetiver_ptype,keras.engine.training.Model)
S3method(vetiver_ptype,kproto)
S3method(vetiver_ptype,lm)
S3method(vetiver_ptype,luz_module_fitted)
S3method(vetiver_ptype,model_stack)
S3method(vetiver_ptype,ranger)
S3method(vetiver_ptype,recipe)
S3method(vetiver_ptype,train)
S3method(vetiver_ptype,workflow)
S3method(vetiver_ptype,xgb.Booster)
S3method(vetiver_python_requirements,default)
S3method(vetiver_python_requirements,keras.engine.training.Model)
S3method(vetiver_renviron_requirements,default)
S3method(vetiver_renviron_requirements,luz_module_fitted)
export(api_spec)
export(attach_pkgs)
export(augment)
export(get_vetiver_dashboard_pins)
export(glue_spec_summary)
export(handler_predict)
export(handler_startup)
export(load_pkgs)
export(map_request_body)
export(new_vetiver_model)
export(pin_example_kc_housing_model)
export(required_pkgs)
export(vetiver_api)
export(vetiver_compute_metrics)
export(vetiver_create_description)
export(vetiver_create_meta)
export(vetiver_create_ptype)
export(vetiver_create_rsconnect_bundle)
export(vetiver_dashboard)
export(vetiver_deploy_rsconnect)
export(vetiver_deploy_sagemaker)
export(vetiver_endpoint)
export(vetiver_endpoint_sagemaker)
export(vetiver_meta)
export(vetiver_model)
export(vetiver_pin_metrics)
export(vetiver_pin_read)
export(vetiver_pin_write)
export(vetiver_plot_metrics)
export(vetiver_pr_docs)
export(vetiver_pr_post)
export(vetiver_pr_predict)
export(vetiver_prepare_docker)
export(vetiver_prepare_model)
export(vetiver_ptype)
export(vetiver_python_requirements)
export(vetiver_renviron_requirements)
export(vetiver_sm_build)
export(vetiver_sm_delete)
export(vetiver_sm_endpoint)
export(vetiver_sm_model)
export(vetiver_type_convert)
export(vetiver_write_docker)
export(vetiver_write_plumber)
import(rlang)
importFrom(generics,
  augment,
  required_pkgs
)
importFrom(glue,
  glue,
  glue_collapse
)
importFrom(lifecycle,deprecated)
importFrom(purrr,
  compact,
  list_modify,
  map,
  map_chr,
  map_lgl,
  pluck,
  pmap,
  safely,
  transpose
)
importFrom(stats,predict)
importFrom(utils,
  flush.console,
  head,
  modifyList
)
importFrom(vctrs,
  vec_slice,
  vec_sort
)
