# Generated by the vetiver package; edit with care

library(pins)
library(plumber)
library(rapidoc)
library(vetiver)

# Packages needed to generate model predictions
if (FALSE) {
    library(ranger)
}
b <- board_folder(path = "/tmp/test")
v <- vetiver_pin_read(b, "cars_ranger")

#* @plumber
function(pr) {
    pr |> vetiver_api(v, debug = TRUE, type = "quantiles")
}
