# Generated by the vetiver package; edit with care

library(pins)
library(plumber)
library(rapidoc)
library(vetiver)

# Packages needed to generate model predictions
if (FALSE) {
    library(xgboost)
}
b <- board_folder(path = "/tmp/test")
v <- vetiver_pin_read(b, "cars_xgb", version = "20220211T213735Z-cc767")

#* @plumber
function(pr) {
    pr |> vetiver_api(v)
}
