# Generated by the vetiver package; edit with care

library(pins)
library(plumber)
library(rapidoc)
library(vetiver)
b <- board_folder(path = "/tmp/test")
v <- vetiver_pin_read(b, "cars_linear", version = "20220211T213712Z-522c5")

#* @plumber
function(pr) {
    pr |> vetiver_api(v)
}
