# Generated by the vetiver package; edit with care

library(pins)
library(plumber)
library(rapidoc)
library(vetiver)

# Packages needed to generate model predictions
if (FALSE) {
    library(dials)
    library(dplyr)
    library(LiblineaR)
    library(parsnip)
    library(purrr)
    library(recipes)
    library(rlang)
    library(rsample)
    library(tibble)
    library(tidyr)
    library(tune)
    library(vctrs)
    library(workflows)
    library(yardstick)
}
b <- board_folder(path = "/tmp/test")
v <- vetiver_pin_read(b, "biv_svm", version = "20220211T213615Z-182ed")

#* @plumber
function(pr) {
    pr |> vetiver_api(v)
}
