# Generated by the vetiver package; edit with care

library(pins)
library(plumber)
library(rapidoc)
library(vetiver)

# Packages needed to generate model predictions
if (FALSE) {
    library(dials)
    library(dplyr)
    library(LiblineaR)
    library(parsnip)
    library(purrr)
    library(recipes)
    library(rlang)
    library(rsample)
    library(textrecipes)
    library(themis)
    library(tibble)
    library(tidyr)
    library(tune)
    library(vctrs)
    library(workflows)
    library(yardstick)
}
b <- board_rsconnect("envvar", server = "https://colorado.rstudio.com/rsc")
v <- vetiver_pin_read(b, "julia.silge/netflix_descriptions", version = "53336")

#* @plumber
function(pr) {
    pr |> vetiver_api(v, debug = TRUE)
}
