# Who maintains Vetiver

The vetiver package was created by and is currently maintained by Isabel Zimmerman <isabel.zimmerman@posit.co>. [Posit Software, PBC](https://posit.co/products/open-source/) is a copyright holder and funder of the vetiver package.

Several individuals in the community have taken an active role in helping to maintain vetiver and submit fixes. Those individuals are shown in the git changelog.
