# mlr3 learner description can be printed

    Code
      v
    Output
      
      -- rpart_penguins - <LearnerClassifRpart> model for deployment 
      A mlr3 classif.rpart learner using 7 features

# create plumber.R for mlr3

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(mlr3)
          library(rpart)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "rpart_penguins")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

