# can print glm model

    Code
      v
    Output
      
      -- cars_glm - <butchered_glm> model for deployment 
      A generalized linear model (gaussian family, identity link) using 10 features

# create plumber.R for glm

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars_glm")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

