# can print gam model

    Code
      v
    Output
      
      -- cars_gam - <butchered_gam> model for deployment 
      A generalized additive model (gaussian family, identity link) using 2 features

# create plumber.R for gam

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(mgcv)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars_gam")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

