# can print tidymodels model

    Code
      v
    Output
      
      -- cars_wf - <bundled_workflow> model for deployment 
      A ranger regression modeling workflow using 10 features

# create plumber.R for tidymodels

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(parsnip)
          library(ranger)
          library(workflows)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars_wf")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

