# can print caret model

    Code
      v
    Output
      
      -- cars_rf - <bundled_train> model for deployment 
      A random forest regression model using 3 features

# create plumber.R for xgboost

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(caret)
          library(dplyr)
          library(e1071)
          library(ranger)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars_rf")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

