# can print recipe

    Code
      v
    Output
      
      -- car-splines - <bundled_recipe> model for deployment 
      A feature engineering recipe with 1 step using 2 features

# create plumber.R for recipe

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(recipes)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "car-splines")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

