# can print kproto model

    Code
      v
    Output
      
      -- kproto-example - <butchered_kproto> model for deployment 
      A k-prototypes clustering model (3 clusters) using 3 features

# create plumber.R for kproto

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(clustMixType)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "kproto-example")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

