# can print xgboost model

    Code
      v
    Output
      
      -- cars2 - <bundled_xgboost> model for deployment 
      An xgboost reg:squarederror model using 10 features

# create plumber.R for xgboost

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(xgboost)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars2")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

