# can print int_conformal_split model

    Code
      v_split
    Output
      
      -- cars_int_split - <butchered_int_conformal_split> model for deployment 
      A Split Conformal inference with a ranger regression model using 10 features

# create plumber.R for int_conformal_split

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(parsnip)
          library(probably)
          library(ranger)
          library(workflows)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars_int_split")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

# can print int_conformal_full model

    Code
      v_full
    Output
      
      -- cars_int_full - <butchered_int_conformal_full> model for deployment 
      A full Conformal inference with a ranger regression model using 10 features

# create plumber.R for int_conformal_full

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(parsnip)
          library(probably)
          library(ranger)
          library(workflows)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars_int_full")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

# can print int_conformal_quantile model

    Code
      v_quantile
    Output
      
      -- cars_int_quantile - <butchered_int_conformal_quantile> model for deployment 
      A quantile Conformal inference with a ranger regression model using 10 features

# create plumber.R for int_conformal_quantile

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(parsnip)
          library(probably)
          library(ranger)
          library(workflows)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars_int_quantile")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

# can print int_conformal_cv model

    Code
      v_cv
    Output
      
      -- cars_int_cv - <butchered_int_conformal_cv> model for deployment 
      A 10-fold CV+ Conformal inference with a ranger regression model using 10
      features

# create plumber.R for int_conformal_cv

    Code
      cat(readr::read_lines(tmp), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      
      # Packages needed to generate model predictions
      if (FALSE) {
          library(parsnip)
          library(probably)
          library(ranger)
          library(workflows)
      }
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars_int_cv")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

