# can pin a model

    Code
      v
    Output
      
      -- cars1 - <butchered_lm> model for deployment 
      An OLS linear regression model using 2 features

# can pin a model with no prototype

    The `save_ptype` argument of `vetiver_model()` is deprecated as of vetiver 0.2.0.
    i Please use the `save_prototype` argument instead.

# right message for reading with `check_renv`

    There is no lockfile stored with "cars5":
    i Use `check_renv = TRUE` when you save your model to your board

