# create rsconnect bundle / contains correct plumber file

    Code
      cat(readr::read_lines(fs::path(tmp_dir, "plumber.R")), sep = "\n")
    Output
      # Generated by the vetiver package; edit with care
      
      library(pins)
      library(plumber)
      library(rapidoc)
      library(vetiver)
      b <- board_folder(path = "<redacted>")
      v <- vetiver_pin_read(b, "cars1")
      
      #* @plumber
      function(pr) {
          pr |> vetiver_api(v)
      }

