# old function is deprecated

    `vetiver_pr_predict()` was deprecated in vetiver 0.1.2 and is now defunct.
    i Please use `vetiver_api()` instead.

# OpenAPI spec for check_prototype = FALSE

    The `check_ptype` argument of `vetiver_pr_post()` is deprecated as of vetiver 0.2.0.
    i Please use the `check_prototype` argument instead.

