% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vetiver-package.R
\docType{import}
\name{reexports}
\alias{reexports}
\alias{augment}
\alias{required_pkgs}
\title{Objects exported from other packages}
\keyword{internal}
\description{
These objects are imported from other packages. Follow the links
below to see their documentation.

\describe{
  \item{generics}{\code{\link[generics:augment]{augment()}}, \code{\link[generics:required_pkgs]{required_pkgs()}}}
}}

